### Issue description

Include a description of the issue encountered, and what the expected behavior
was. Also include any configuration, test suite, or other relevant information
to reproduce the issue.

Note if you encounter an error message try to re-run the command with --debug to print any tracebacks

#### Expected behavior and actual behavior

#### Steps to reproduce the problem

#### Specifications like the version of the project, operating system, or hardware

### System information

**stestr version (`stestr --version`):**

**Python release (`python --version`):**

**pip packages (`pip freeze`):**


### Additional information
